tinsel.utils

Some utilities of use elsewhere.

Some utilities of use elsewhere.
raw docstring

attrsclj

(attrs node)

Given a normalized hiccup node, returns the attribute map.

Given a normalized hiccup node, returns the attribute map.
raw docstring

code-form?clj

(code-form? form)

Takes a form and returns true if it is a 'code' form. In other words, it is attempting to express code to be executed for its content, instead of being a marker for hiccup to process into HTML.

Takes a form and returns true if it is a 'code' form. In other words,
it is attempting to express code to be executed for its content, instead
of being a marker for hiccup to process into HTML.
raw docstring

contentsclj

(contents node)

Given a normalized hiccup node, returns the content as a seq.

Given a normalized hiccup node, returns the content as a seq.
raw docstring

nameclj

(name x)

Given a string, keyword, or symbol, returns its name as a string. Otherwise, nil. This exists because clojure.core/name will blow up with a NullPointerException if you pass in nil and this easier than checking for nil everywhere.

Given a string, keyword, or symbol, returns its name as a string.
Otherwise, nil. This exists because clojure.core/name will blow up with a
NullPointerException if you pass in nil and this easier than checking for
nil everywhere.
raw docstring

normalize-formclj

(normalize-form form)

Given a hiccup form, recursively normalizes it using normalize-element.

Given a hiccup form, recursively normalizes it using
normalize-element.
raw docstring

tagclj

(tag node)

Given a normalized hiccup node, returns the tag as a string.

Given a normalized hiccup node, returns the tag as a string.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries