Some utilities of use elsewhere.
Some utilities of use elsewhere.
(attrs node)Given a normalized hiccup node, returns the attribute map.
Given a normalized hiccup node, returns the attribute map.
(code-form? form)Takes a form and returns true if it is a 'code' form. In other words, it is attempting to express code to be executed for its content, instead of being a marker for hiccup to process into HTML.
Takes a form and returns true if it is a 'code' form. In other words, it is attempting to express code to be executed for its content, instead of being a marker for hiccup to process into HTML.
(contents node)Given a normalized hiccup node, returns the content as a seq.
Given a normalized hiccup node, returns the content as a seq.
(name x)Given a string, keyword, or symbol, returns its name as a string. Otherwise, nil. This exists because clojure.core/name will blow up with a NullPointerException if you pass in nil and this easier than checking for nil everywhere.
Given a string, keyword, or symbol, returns its name as a string. Otherwise, nil. This exists because clojure.core/name will blow up with a NullPointerException if you pass in nil and this easier than checking for nil everywhere.
(normalize-form form)Given a hiccup form, recursively normalizes it using normalize-element.
Given a hiccup form, recursively normalizes it using normalize-element.
(tag node)Given a normalized hiccup node, returns the tag as a string.
Given a normalized hiccup node, returns the tag as a string.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |